Struct AttributeList
pub struct AttributeList<'a>(/* private fields */);Implementations
impl<'a> AttributeList<'a>
Attributes for nodes in the PDF tree.
impl<'a> AttributeList<'a>
Attributes for nodes in the PDF tree.
Each attribute must have an owner (e.g. “Layout”, “List”, “Table”, etc) and an attribute name (e.g. “BBox”, “RowSpan”, etc.) from PDF32000_2008 14.8.5, and then a value of the proper type according to the spec.
Parameters of type CString will not be copied and the pointers must remain valid until
crate::Document::close or crate::Document::abort is called.
Names are expected to be constants and are taken as CString.
Parameters not taken as CString will be copied.
pub fn append_int( &mut self, owner: &'a CString, name: &'a CString, value: i32, ) -> &mut AttributeList<'a>
pub fn append_float( &mut self, owner: &'a CString, name: &'a CString, value: f32, ) -> &mut AttributeList<'a>
pub fn append_float_array( &mut self, owner: &'a CString, name: &'a CString, value: &[f32], ) -> &mut AttributeList<'a>
pub fn append_name( &mut self, owner: &'a CString, name: &'a CString, value: &'a CString, ) -> &mut AttributeList<'a>
pub fn append_text_string( &mut self, owner: &'a CString, name: &'a CString, value: &'a CString, ) -> &mut AttributeList<'a>
pub fn append_node_id_array( &mut self, owner: &'a CString, name: &'a CString, node_ids: &[i32], ) -> &mut AttributeList<'a>